@@ -67,13 +67,23 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 our @ISA = qw{Exporter};
 
 use Carp;
 use Data::Dumper;
 use POSIX qw{floor strftime};
-use Time::y2038;
+
+BEGIN {
+    eval {
+	require Time::y2038;
+	Time::y2038->import();
+	1;
+    } or do {
+	require Time::Local;
+	Time::Local->import();
+    };
+}
 
 our @EXPORT;
 our @EXPORT_OK = qw{
@@ -265,6 +275,10 @@ sets of Cartesian coordinates. We do not take the square root here
 because of cases (e.g. the law of cosines) where we would just have
 to square the result again.
 
+B<Notice> that the subroutine does B<not> assume three-dimensional
+coordinates. If @coord1 and @coord2 have six entries, you will get a
+six-dimensional distance.
+
 =cut
 
 sub distsq {
